pub struct GreekColumns {
pub delta: bool,
pub gamma: bool,
pub vega: bool,
pub theta: bool,
}Expand description
Which optional Greek columns are visible for a given number of extra column
slots that fit (docs/05-views-and-ux.md 8). Δ is always visible.
Fields
delta: boolDelta — always true.
gamma: boolGamma — shown only when there is width for all three optional columns.
vega: boolVega — shown when there is width for at least two.
theta: boolTheta — shown when there is width for at least one (dropped last).